calcWHPT_AB: Calculate abundance-weighted WHPT indices
Description
Calculates WHPT abundance-weighted ASPT and N-taxa indices
for invertebrate samples.
Usage
calcWHPT_AB(df, type = "num")
Arguments
df
A dataframe containing list of taxa in first column, followed by
columns of abundances with sample names in header row.
type
Indicates format of data. Options are "num" for numeric data,
"log" for integer log abundance categories (1-5) or "alpha" for alphabetic
abundance categories (A-E). Default value is "num".
Value
A data frame consisting of columns of index values with samples
in rows.
# calculate the WHPT abundance-weighted indices for the River Almond dataset# data are numeric abundances, so type is "num" (can be omitted)calcWHPT_AB(almond, "num")