Learn R Programming

biotic (version 0.1.2)

calcWhalley: Calculate Whalley revised BMWP indices for invertebrate samples

Description

Calculates Whalley revised BMWP, ASPT and N-taxa indices for invertebrate samples.

Usage

calcWhalley(df, type = "num")

Arguments

df
A dataframe containing list of taxa in first column, followed by columns of abundances with sample names in header row.
type
Indicates format of data. Options are "num" for numeric data, "log" for integer log abundance categories (1-5) or "alpha" for alphabetic abundance categories (A-E). Default value is "num".

Value

A data frame consisting of columns of index values with samples in rows.

Examples

Run this code

# calculate the Whalley revised BMWP indices for the Green Burn dataset
# data are numeric log abundance categories, so type is "log"

calcWhalley(greenburn, "log")

Run the code above in your browser using DataLab