Learn R Programming

biotic (version 0.1.2)

checktaxa: Check taxa against scoring list

Description

Check the list of taxa present in the sample dataset against the list of scoring taxa within package to identify any non-scoring taxa in the samples (or spelling mistakes).

Usage

checktaxa(df)

Arguments

df
A dataframe containing abundances of invertebrate taxa in different samples.

Value

A data frame containing the names of taxa that are not in the list of scoring taxa, or NA if all taxa are scoring.

Examples

Run this code
# check the taxa in the built-in Braid Burn dataset
# returns 'NA' if all taxa present have scores and are spelt correctly

checktaxa(braidburn)

Run the code above in your browser using DataLab