Check the list of taxa present in the sample dataset against
the list of scoring taxa within package to identify any non-scoring taxa
in the samples (or spelling mistakes).
Usage
checktaxa(df)
Arguments
df
A dataframe containing abundances of invertebrate taxa in
different samples.
Value
A data frame containing the names of taxa that are not in the
list of scoring taxa, or NA if all taxa are scoring.